"""Internal module for loading proxy-related env variables"""
import logging
import os
from typing import Optional

_default_logger = logging.getLogger(__name__)


def load_http_proxy_from_env(logger: logging.Logger = _default_logger) -> Optional[str]:
    proxy_url = (
        os.environ.get("HTTPS_PROXY")
        or os.environ.get("https_proxy")
        or os.environ.get("HTTP_PROXY")
        or os.environ.get("http_proxy")
    )
    if proxy_url is None:
        return None
    if len(proxy_url.strip()) == 0:
        # If the value is an empty string, the intention should be unsetting it
        logger.debug(
            "The Slack SDK ignored the proxy env variable as an empty value is set."
        )
        return None

    logger.debug(f"HTTP proxy URL has been loaded from an env variable: {proxy_url}")
    return proxy_url



from typing import List

from .handler import RetryHandler  # noqa
from .builtin_handlers import (
    ConnectionErrorRetryHandler,  # noqa
    RateLimitErrorRetryHandler,  # noqa
)  # noqa
from .interval_calculator import RetryIntervalCalculator  # noqa
from .builtin_interval_calculators import (  # noqa
    FixedValueRetryIntervalCalculator,  # noqa
    BackoffRetryIntervalCalculator,  # noqa
)  # noqa
from .jitter import Jitter  # noqa
from .request import HttpRequest  # noqa
from .response import HttpResponse  # noqa
from .state import RetryState  # noqa

connect_error_retry_handler = ConnectionErrorRetryHandler()  # noqa
rate_limit_error_retry_handler = RateLimitErrorRetryHandler()  # noqa


def default_retry_handlers() -> List[RetryHandler]:
    return [connect_error_retry_handler]


def all_builtin_retry_handlers() -> List[RetryHandler]:
    return [
        connect_error_retry_handler,
        rate_limit_error_retry_handler,
    ]
